function r2usm=renyi2usm_fast(cgr,sig2v,refseq,opts)

% function r2usm=renyi2usm_fast(cgr,sig2v,refseq,opts)
% Calculates Renyi quadratic entropy of a set of 4D USM fwd coordinates
% renyi2 in 4D with parzen window method, with gaussian kernel G(0,sig2*I) simplifies - see renyi.tex
% r2usm = -ln( integral(p^2) ) = -ln( 1/n^2 * sum_i(sum_j(G(xi-yj),2sig2*I)) )
% INPUT:
%   cgr -> cgr coordinates with 1st column with xx' coordinates and 2nd
%           column with yy' coordinates, 3rd colum ww' and 4th column zz'
%   sig2v -> vector with variances sig2 used to Parzen method
%   refseq -> sequence name, used to output files
%   opts -> option save results to file(=1default), 0-don't save
% OUTPUT:
%   r2usm -> renyi quadratic entropy of usm
% ---
% See also (based in): renyi2.m; renyi2usm.m; renyi2usm_fast_old.m
% Susana Vinga, 2003-11-18
% 2003-01-08 further simplication with vectorization of pdist, reduces time
% more that 4 fold
%2004.03.24, add textread(fich) - doesn't work with opts=0 - correct
%2004.04.26 alter precision when writing to *.rn2

C=cgr(:,1:4);   %each line is one observation in R4
% x=cgr(:,1);
% y=cgr(:,2);
% z=cgr(:,3);
% w=cgr(:,4);

%n=length(x);    %sequence length -> n
[n,aux]=size(C);    % n is sequence length

if nargin<4
    opts=1;  %save results to *.rn2
end

% dx=crossd_v(x);
% dy=crossd_v(y);
% dz=crossd_v(z);
% dw=crossd_v(w);

dC=pdist(C);    % eulidean distance, dim=n*(n-1)/2
dC=dC.^2;   %squared euclidean distance: corresponds to dij - see paper
% dx=pdist(x);
% dy=pdist(y);
% dz=pdist(z);
% dw=pdist(w);

%d0=zeros(n,1);  %dii -> diagonal of dissimilarity matrices


if opts
    fich=['renyi2usm_' refseq '.rn2'];
    fid=fopen(fich,'w');
    fprintf(fid,'### USM Renyi quadratic entropy vs sigma2 for seq: %s - Created in %s\n',refseq,datestr(now));
    fprintf(fid, '###---sig2------renyi2---\n');
end

%%%###vector sig2
for i=1:length(sig2v);
    sig2=sig2v(i);
    if opts; disp(['sig2 = ' num2str(sig2)]);end;
    sig=sqrt(sig2); %to use in normpdf
    
    %     Gdx=normpdf2(dx,0,sqrt(2*sig2));
    %     Gdy=normpdf2(dy,0,sqrt(2*sig2));
    %     Gdz=normpdf2(dz,0,sqrt(2*sig2));
    %     Gdw=normpdf2(dw,0,sqrt(2*sig2));
    %     
    %     Gd0=normpdf2(0,0,sqrt(2*sig2));
    %     Gd0=Gd0^4;
    %     
    %     
    %     %Gtot=Gdx.*Gdy.*Gdz.*Gdw;   %product of the marginals for decorrelated gaussians
    %     Gtot=Gdx.*Gdy.*Gdz.*Gdw;   %product of the marginals for decorrelated gaussians
    %     
    %     V=(1/n^2) * (2*sum(Gtot)+n*Gd0);
    
    G=2*sum( exp(-1/(4*sig2) * dC) ) + n;
    V=1/(n^2*16*pi^2*sig2^2) * G;
    r2usm = -log(V);   %natural logarithm
    
    
    if opts
        fprintf(fid,'%d\t%.17d\n',sig2,r2usm); 
    end
end

if opts
    disp(['##Renyi2 file: ' fich])
    fclose(fid);
    [t,r2usm]=textread(fich,'%f %f','commentstyle','shell'); %importdata works only for big files (above 7sig2?)
end