function SIM=simul_renyi_usm2(N,sig2,nrep)

% SIMUL_RENYI_USM2 simulation of renyi quadratic entropy - CGR coord. not unif
% function r2=simul_renyi_usm2(N,sig2)
% Calculates Renyi quadratic entropy of random 4D USM vectors - 2nd version
% Input-> N - number of coordinates do simulate
%         sig2 variance of parzen gaussian for estimation
%         nrep number of replicas for the simulation=nb of sequences to
%         simulate
% Output-> SIM [nrep x sig2] renyi quadratic entropy based on pdf estimation by parzen method
% Creates file ['N' num2str(N) 'R' num2str(nrep) '.sim'] with results
% See also: simul_renyi_usm.m
% Susana Vinga, 2004-04-20 - alter precition, 2004.04.26, 2004.09.20 cancel name2

name=['N' num2str(N) 'R' num2str(nrep) '.sim'];
%name2=['N' num2str(N) 'R' num2str(nrep)];

if exist(name)  %if the simulation for this case was already made, don't do it again!
    disp(['***Simulation is already saved!!! Reading from file: ' name]);
else    %has to do the simulation
    disp(['***Simulation is not saved. Running ' num2str(nrep) ' replicas for length N=' num2str(N)])
    fid=fopen(name,'w');
    disp('Replica nb...');
    for i=1:nrep
        disp(['...' num2str(i)]);
        %simulate coordinates
        c=randUSM(N,1);
        %calculate renyi entropies
        r2=renyi2usm_fast(c,sig2,'AUX',1);
        fprintf(fid,'%.17d\n',r2);
    end
    fclose(fid);
end

%read files
SIM=importdata(name);
SIM=reshape(SIM,length(sig2),nrep);
SIM=SIM';

%figure;plot(log(sig2),median(SIM,1),'.-');xlabel('ln\sigma^2');ylabel('Median H2 values for simulation');grid;
%saveas(gcf,['SH2med' name2 '.fig'],'fig');
%falta a diferencial
%figure;plot(log(sig2(1:end-1)),diff(median(SIM,1))/(0.25*log(10)),'.-');xlabel('ln\sigma^2');ylabel('Renyi differential entropy');grid;
%saveas(gcf,['SdH2med' name2 '.fig'],'fig');

%figure;plot(log(sig2),std(SIM,0,1),'.-');xlabel('ln\sigma^2');ylabel('Std H2 values for simulation');grid;
%saveas(gcf,['SH2std' name2 '.fig'],'fig');

disp(['### FILE created/read: ' name]);