function [r,n]=usm_entropy(c,L,alpha)

% function [r,n]=usm_entropy(c,n,alpha)
% calculates entropy of USM map coordinates
% c -> USM coordinates
% L -> L-tuple, number of USM divisions in each coordinate n=2^L
% alpha -> parameter for renyi entropy, if 1=shannon's
% r -> renyi entropy in bits!!! log2 units
% n -> vector of L-tuple counts
% calls entropy_renyi.m, see also cgr_entropy
% Susana Vinga, 2004.03.24

c=c(:,1:4);  %just forward coordinates
d=2^L; %number of division for each coordinate
nbin=d^2;   %total number of bins or usm subquadrants

%L-tuple=1 -> d=2;
%L-tuple=2 -> d=4;
%L-tuple=3 -> d=8;
%L -> d=2^L; nbin=(2^L)^2=4^L %all possible L-tuples in DNA

t=floor(2^L*c(L:end,:));
[B,I,J] = unique(t,'rows');
n=histc(J,1:nbin);
r=entropy_renyi(n,alpha);
